@@ -22,10 +22,10 @@ module CheckpointCutsEvent (main) where
 
 -- import           Control.Concurrent
 import           Control.Applicative
-import           Control.Monad.Reader
-import           Control.Monad.State
+import           Control.Monad
+import           Control.Monad.State  ( get, put )
 import           Data.Acid
-import           Data.List
+import           Data.List            ( sort )
 import           Data.SafeCopy
 import           Data.Typeable
 import           System.Directory
